@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package Plack::Middleware::Cleanup;
 {
-  $Plack::Middleware::Cleanup::VERSION = '0.002';
+  $Plack::Middleware::Cleanup::VERSION = '0.003';
 }
 # ABSTRACT: Run cleanup code after request completion
 
@@ -23,9 +23,10 @@ sub call {
     return $self->app->($env);
 }
 
+
 package Plack::Middleware::Cleanup::Guard;
 {
-  $Plack::Middleware::Cleanup::Guard::VERSION = '0.002';
+  $Plack::Middleware::Cleanup::Guard::VERSION = '0.003';
 }
 
 sub DESTROY { $_[0]->() }
@@ -41,10 +42,14 @@ Plack::Middleware::Cleanup - Run cleanup code after request completion
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
+Don't use this module.  It has some serious flaws.  See this proposal instead:
+
+https://github.com/miyagawa/psgi-specs/wiki/Proposal%3A-PSGI-environment-cleanup-handlers
+
     my $app = sub {
         my $env = shift;
         $env->{'cleanup.register'}->(sub {
@@ -72,6 +77,14 @@ after the request is complete.
 Make sure your coderefs do not accidentally refer to C<< $env >>, or you will
 have a circular reference and leak memory (also, your coderefs will never run).
 
+This will only work properly on handlers that happen to let C<< $env >> fall out
+of scope at the right time, e.g. FCGI.  It will not work correctly, for
+example, on CGI or mod_perl.
+
+=head1 SEE ALSO
+
+L<Catalyst::Plugin::RunAfterRequest>
+
 =head1 AUTHOR
 
 Hans Dieter Pearcey <hdp@pobox.com>
